@@ -4,6 +4,7 @@ import re
 import time
 import glob
 from collections import defaultdict
+from datetime import datetime
 
 import requests
 import lxml.etree as ET
@@ -393,12 +394,54 @@ class FrdManifestation(FrdClient):
 
     def get_man_json_dump(self, lmt=True):
         json_dump = {}
-        json_dump["id"] = f"bibl__{self.manifestation_id}"
-        json_dump["browser_url"] = f"{self.browser}{self.manifestation_folder}"
+        json_dump['id'] = f"bibl__{self.manifestation_id}"
+        json_dump['browser_url'] = f"{self.browser}{self.manifestation_folder}"
         man_type = self.manifestation['data']['type'].replace('--', '/')
-        json_dump["url"] = f"{self.endpoint}{man_type}/{self.manifestation_id}"
+        json_dump['url'] = f"{self.endpoint}{man_type}/{self.manifestation_id}"
         json_dump['man_title'] = self.md__title
         json_dump['signature'] = self.manifestation_signatur
+        try:
+            field_status = self.manifestation['data']['attributes']['field_status_umschrift']
+            if field_status == 2:
+                field_name = "complete"
+                field_status = str(field_status)
+            elif field_status is None:
+                field_name = "proposed"
+                field_status = "0"
+            else:
+                field_name = "undefined"
+                field_status = str(field_status)
+            d = datetime.now()
+            dt = f"{d.year}-{d.month}-{d.day}"
+            json_dump['status'] = {
+                "id": field_status,
+                "name": field_name,
+                "date": dt
+            }
+        except (KeyError, TypeError):
+            json_dump['status'] = {}
+        try:
+            man_type_name = self.manifestation_typ['data']['attributes']['name']
+            man_type_id = self.manifestation_typ['data']['id']
+            man_type_type = self.manifestation_typ['data']['type']
+            json_dump['man_doc_type'] = {
+                "id": man_type_id,
+                "type": man_type_type,
+                "name": man_type_name
+            }
+        except (KeyError, TypeError):
+            json_dump['man_doc_type'] = {}
+        try:
+            doc_type_name = self.doc_component['data']['attributes']['name']
+            doc_type_id = self.doc_component['data']['id']
+            doc_type_type = self.doc_component['data']['type']
+            json_dump['doc_component'] = {
+                "id": doc_type_id,
+                "type": doc_type_type,
+                "name": doc_type_name
+            }
+        except (KeyError, TypeError):
+            json_dump['doc_component'] = {}
         try:
             json_dump['note_i'] = self.manifestation['data']['attributes']['field_anmerkung_intern_']['processed']
         except (KeyError, TypeError):
@@ -416,7 +459,7 @@ class FrdManifestation(FrdClient):
                 "value": field_date['value'],
                 "end_value": field_date['end_value']
             }
-        except(KeyError, TypeError):
+        except (KeyError, TypeError):
             json_dump['date'] = {}
             print("manifestation has no field_datum.")
         try:
@@ -426,7 +469,7 @@ class FrdManifestation(FrdClient):
                 "name": field_reihe,
                 "number": field_reihe_no
             }
-        except(KeyError, TypeError):
+        except (KeyError, TypeError):
             json_dump['reihe'] = {}
             print("manifestation has no field_reihe")
         try:
@@ -732,7 +775,7 @@ class FrdManifestation(FrdClient):
                 "name": field_reihe,
                 "number": field_reihe_no
             }
-        except(KeyError, TypeError):
+        except (KeyError, TypeError):
             print("publication has no field_reihe")
         try:
             edition = init_methods['pub_edition']['data']['attributes']['name']
@@ -990,6 +1033,8 @@ class FrdManifestation(FrdClient):
         self.sprache = self.get_fields_any('field_sprache')
         self.type = self.get_fields_any('field_publication_type')
         self.edition = self.get_fields_any('field_edition')
+        self.doc_component = self.get_fields_any('field_doc_component')
+        self.manifestation_typ = self.get_fields_any('field_manifestation_typ')
         # first level publication
         self.publication = self.get_fields_any('field_published_in')
         self.pub_publisher = self.get_fields_any_any('field_publisher', self.publication)
@@ -1229,32 +1274,36 @@ def make_xml(workpath, out_dir, dump, save=False, test=False):
             try:
                 with open(x, 'r', encoding='utf8') as f:
                     json_dump = json.load(f)
-            except FileNotFoundError:
-                print(f"file {x} not found, run get_man_json_dump() function first")
-            json_dump['publicationHistory'] = []
-            history = glob.glob(os.path.join(out_dir, workpath, "data", "*.json"))
-            for x in history:
-                try:
-                    with open(x, 'r', encoding='utf8') as f:
-                        json_dump['publicationHistory'].append(
-                            json.load(f)
-                        )
-                except FileNotFoundError:
-                    print("no json dump found")
-            templateLoader = jinja2.PackageLoader(
-                "freud_api_crawler", "templates"
-            )
-            templateEnv = jinja2.Environment(loader=templateLoader, trim_blocks=True, lstrip_blocks=True)
-            template = templateEnv.get_template('./tei.xml')
-            tei = template.render({"objects": [json_dump]})
-            tei = re.sub(r'\s+$', '', tei, flags=re.MULTILINE)
-            tei = ET.fromstring(tei)
-            transform = ET.XSLT(XSL_DOC)
-            tei = transform(tei)
-            if save:
-                signatur = json_dump["signature"]
-                filename = signatur.replace("/", "__")
-                savepath = os.path.join(out_dir, workpath)
-                with open(os.path.join(savepath, f"sfe-{filename}.xml"), 'wb') as f:
-                    f.write(ET.tostring(tei, pretty_print=True, encoding="utf-8"))
+            except Exception as e:
+                json_dump = {}
+                print(f"file {x} not found, run get_man_json_dump() function first. Error: {e}")
+            if json_dump:
+                json_dump['publicationHistory'] = []
+                history = glob.glob(os.path.join(out_dir, workpath, "data", "*.json"))
+                for x in history:
+                    try:
+                        with open(x, 'r', encoding='utf8') as f:
+                            json_dump['publicationHistory'].append(
+                                json.load(f)
+                            )
+                    except FileNotFoundError:
+                        print("no json dump found")
+                templateLoader = jinja2.PackageLoader(
+                    "freud_api_crawler", "templates"
+                )
+                templateEnv = jinja2.Environment(loader=templateLoader, trim_blocks=True, lstrip_blocks=True)
+                template = templateEnv.get_template('./tei.xml')
+                tei = template.render({"objects": [json_dump]})
+                tei = re.sub(r'\s+$', '', tei, flags=re.MULTILINE)
+                tei = ET.fromstring(tei)
+                transform = ET.XSLT(XSL_DOC)
+                tei = transform(tei)
+                if save:
+                    signatur = json_dump["signature"]
+                    filename = signatur.replace("/", "__")
+                    savepath = os.path.join(out_dir, workpath)
+                    with open(os.path.join(savepath, f"sfe-{filename}.xml"), 'wb') as f:
+                        f.write(ET.tostring(tei, pretty_print=True, encoding="utf-8"))
+            else:
+                tei = None
     return tei
